@@ -78,16 +78,6 @@ void IEEEXploreSearcher::saveConfig(KConfig* config)
 
 void IEEEXploreSearcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , const QString& value1, const QString& value2, const QString& value3, int operator1, int operator2)
 {
-    cerr << "Searching IEEEXplore\n";
-    m_started = true;
-
-    m_data.truncate(0);
-
-    m_url = KURL(m_host);
-    if (m_freeSearch)
-        m_url.addPath(QString::fromLatin1("search/freesearchresult.jsp"));
-    else
-        m_url.addPath(QString::fromLatin1("search/searchresult.jsp"));
 
     QString str;
     m_query = QString();
@@ -235,23 +225,43 @@ void IEEEXploreSearcher::search(SearchKey key1, SearchKey key2, SearchKey key3 ,
 
     }
 
+	search(m_query);
+}
+
+void IEEEXploreSearcher::search(QString query){
+//    cerr << "Query string = " << query << "\n";
+    m_query = query;
 
     if (m_query.isEmpty())
     {
         stop();
         return;
     }
+
+	
+	m_started = true;
+
+    m_data.truncate(0);
+
+    m_url = KURL(m_host);
+    if (m_freeSearch)
+        m_url.addPath(QString::fromLatin1("search/freesearchresult.jsp"));
+    else
+        m_url.addPath(QString::fromLatin1("search/searchresult.jsp"));
+
+
     m_url.addQueryItem(QString::fromLatin1("queryText"), m_query);
     m_url.addQueryItem(QString::fromLatin1("ResultCount"), "1");
     m_url.addQueryItem(QString::fromLatin1("ResultStart"), "0");
 
     m_step = Search;
-    std::cerr << m_url.url() << "\n";
+//    std::cerr << m_url.url() << "\n";
     m_job = KIO::get(m_url, false, false);
     connect(m_job, SIGNAL(data(KIO::Job*, const QByteArray&)),
             SLOT(slotData(KIO::Job*, const QByteArray&)));
     connect(m_job, SIGNAL(result(KIO::Job*)),
             SLOT(slotComplete(KIO::Job*)));
+	
 
 }
 
