@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sat May 31 2003
     copyright            : (C) 2003 by Thach NguyenF
-    email                : thach@dragon.thach.com
+    email                : thach.nguyen@rmit.edu.au
  ***************************************************************************/
 
 /***************************************************************************
@@ -53,11 +53,11 @@ KBibEditEntryDlg::KBibEditEntryDlg ( BibEntry *entry, QWidget *parent, const cha
 	entryTypeLabel = new QLabel ( i18n ( "Reference Type:" ), box1 );
 	entryTypeLabel->setMinimumWidth ( 140 );
 	entryTypeSelect = new QComboBox ( false, box1, "entryType" );
-	entryTypeLabel->setBuddy(entryTypeSelect);
-	QToolTip::add (entryTypeSelect, QString( i18n("Select the reference type from the list") ) );
+	entryTypeLabel->setBuddy ( entryTypeSelect );
+	QToolTip::add ( entryTypeSelect, QString ( i18n ( "Select the reference type from the list" ) ) );
 	QWhatsThis::add ( entryTypeSelect, QString ( i18n ( "Select from the list the reference type then the dialog will display all defined fields for the selected type. Undefined fields can be added in \"Extra Field\" tab. The reference type can be modified or new type being added using command Customise Reference Type in Bitex menu." ) ) );
-	
-	
+
+
 	//editTypeBttn = new QPushButton("Edit Type", box1);
 	editTypeBttn = new QPushButton ( box1 );
 	// QPixmap editPix = KGlobal::iconLoader()->loadIcon(QString::fromLatin1("edit"), KIcon::Small);
@@ -79,25 +79,25 @@ KBibEditEntryDlg::KBibEditEntryDlg ( BibEntry *entry, QWidget *parent, const cha
 	box2->setMargin ( 4 );
 	box2->setSpacing ( 4 );
 
-	keyLabel = new QLabel ( "Citation Key:", box2 );
+	keyLabel = new QLabel ( i18n("Citation Key:"), box2 );
 	keyLabel->setMinimumWidth ( 140 );
 	keyField = new KLineEdit ( box2 );
 	keyField->setMinimumWidth ( 140 );
-	keyLabel->setBuddy(keyField);
-	QToolTip::add (keyField, QString( i18n("Enter the citation key into this box") ) );
-	QWhatsThis::add ( keyField, QString ( i18n ( "You can enter the citation key directly in this box or click on the %1 to have the citation key created automatically. This box is disable if the citation key is locked." ).arg(i18n("Create Key")) ) );
-	
-	
-	createKeyBttn = new QPushButton (i18n("Create Key"), box2 );
+	keyLabel->setBuddy ( keyField );
+	QToolTip::add ( keyField, QString ( i18n ( "Enter the citation key into this box" ) ) );
+	QWhatsThis::add ( keyField, QString ( i18n ( "You can enter the citation key directly in this box or click on the %1 to have the citation key created automatically. This box is disable if the citation key is locked." ).arg ( i18n ( "Create Key" ) ) ) );
+
+
+	createKeyBttn = new QPushButton ( i18n ( "Create Key" ), box2 );
 	QToolTip::add ( createKeyBttn, QString ( i18n ( "Create citation key" ) ) );
 	QWhatsThis::add ( createKeyBttn, QString ( i18n ( "Click this button to have the citation key created automatically based on author and year fields. This button is disabled when the citation key is locked." ) ) );
-	createKeyBttn->setMinimumWidth (createKeyBttn->sizeHint().width());
+	createKeyBttn->setMinimumWidth ( createKeyBttn->sizeHint().width() );
 	lockKeyBttn = new QPushButton ( box2 );
 	lockKeyBttn->setMinimumWidth ( lockKeyBttn->sizeHint().width() );
-	
+
 	QToolTip::add ( lockKeyBttn, QString ( i18n ( "Lock citation key" ) ) );
 	QWhatsThis::add ( lockKeyBttn, QString ( i18n ( "Click this button to toggle locking state of the citation key." ) ) );
-	
+
 	dummy = new QWidget ( box2 );
 	box2->setStretchFactor ( keyLabel, 0 );
 	box2->setStretchFactor ( keyField, 1 );
@@ -110,7 +110,7 @@ KBibEditEntryDlg::KBibEditEntryDlg ( BibEntry *entry, QWidget *parent, const cha
 	l1->addWidget ( reqTab );
 	reqTab->setMargin ( 0 );
 	reqTab->setMinimumHeight ( 200 );
-	
+
 	QToolTip::add ( reqTab, QString ( i18n ( "Fields that are requried for the current reference type." ) ) );
 	QWhatsThis::add ( reqTab, QString ( i18n ( "This tab show all required fields of the current reference type. A required field should not be empty." ) ) );
 
@@ -120,7 +120,7 @@ KBibEditEntryDlg::KBibEditEntryDlg ( BibEntry *entry, QWidget *parent, const cha
 
 	rqScrollView->setFrameStyle ( 0 );
 	rqScrollView->setResizePolicy ( QScrollView::AutoOneFit );
-	reqTab->addTab ( rqScrollView, "Required Fields" );
+	reqTab->addTab ( rqScrollView, i18n("Required Fields") );
 
 	rqBox = new QGroupBox ( rqScrollView->viewport() );
 	rqLayout = new QVBoxLayout ( rqBox, 0, KDialog::spacingHint() );
@@ -143,7 +143,7 @@ KBibEditEntryDlg::KBibEditEntryDlg ( BibEntry *entry, QWidget *parent, const cha
 	optScrollView = new QScrollView ( optTab );
 	optScrollView->setFrameStyle ( 0 );
 	optScrollView->setResizePolicy ( QScrollView::AutoOneFit );
-	optTab->addTab ( optScrollView, "Optional Fields" );
+	optTab->addTab ( optScrollView, i18n("Optional Fields") );
 
 	optBox = new QGroupBox ( optScrollView->viewport() );
 	optLayout = new QVBoxLayout ( optBox, 0, KDialog::spacingHint() );
@@ -166,10 +166,6 @@ KBibEditEntryDlg::KBibEditEntryDlg ( BibEntry *entry, QWidget *parent, const cha
 	optFields.setAutoDelete ( true );
 
 
-
-
-
-
 	rqScrollView->setHScrollBarMode ( QScrollView::AlwaysOff );
 	optScrollView->setHScrollBarMode ( QScrollView::AlwaysOff );
 
@@ -178,7 +174,6 @@ KBibEditEntryDlg::KBibEditEntryDlg ( BibEntry *entry, QWidget *parent, const cha
 	entryTypeSelect->setInsertionPolicy ( QComboBox::NoInsertion );
 
 	if ( entry == 0 )
-		//m_entry = new BibEntry(const_cast<char*>("article"), "");
 		m_entry = new BibEntry ( BibEntryDefTable::self()->getEntryTypeName ( 0 ), "" );
 	else
 		m_entry = new BibEntry ( *entry );
@@ -187,7 +182,7 @@ KBibEditEntryDlg::KBibEditEntryDlg ( BibEntry *entry, QWidget *parent, const cha
 
 	entryTypeSelect->setCurrentText ( entryTypeName );
 
-	mainTab->addTab ( fieldEdit, "&Main Fields" );
+	mainTab->addTab ( fieldEdit, i18n("&Main Fields") );
 	mainTab->setMargin ( 0 );
 
 	//Exttra fields tab
@@ -195,7 +190,7 @@ KBibEditEntryDlg::KBibEditEntryDlg ( BibEntry *entry, QWidget *parent, const cha
 
 	QHBoxLayout* l4 = new QHBoxLayout ( extraFieldTab, 0, KDialog::spacingHint() );
 	l4->setMargin ( 40 );
-	extraFieldView = new QListView ( extraFieldTab );
+	extraFieldView = new KListView ( extraFieldTab );
 	extraFieldView->setAllColumnsShowFocus ( true );
 	extraFieldView->setShowSortIndicator ( false );
 	extraFieldView->setDefaultRenameAction ( QListView::Accept );
@@ -211,9 +206,9 @@ KBibEditEntryDlg::KBibEditEntryDlg ( BibEntry *entry, QWidget *parent, const cha
 
 	QVBoxLayout* box = new QVBoxLayout ( extraFieldTab, 0, KDialog::spacingHint() );
 
-	extraFieldAddBtn = new KPushButton ( "Add", extraFieldTab );
-	extraFieldEditBtn = new KPushButton ( "Edit", extraFieldTab );
-	extraFieldDeleteBtn = new KPushButton ( "Delete", extraFieldTab );
+	extraFieldAddBtn = new KPushButton ( i18n("Add"), extraFieldTab );
+	extraFieldEditBtn = new KPushButton ( i18n("Edit"), extraFieldTab );
+	extraFieldDeleteBtn = new KPushButton ( i18n("Delete"), extraFieldTab );
 
 
 	extraFieldAddBtn->setIconSet ( QIconSet ( SmallIcon ( "add" ) ) );
@@ -235,7 +230,7 @@ KBibEditEntryDlg::KBibEditEntryDlg ( BibEntry *entry, QWidget *parent, const cha
 	connect ( extraFieldDeleteBtn, SIGNAL ( clicked() ), this, SLOT ( slotExtraFieldDelete() ) );
 
 
-	mainTab->addTab ( extraFieldTab, "&Extra Fields" );
+	mainTab->addTab ( extraFieldTab, i18n("&Extra Fields") );
 
 
 	//Abstract Tab
@@ -246,20 +241,20 @@ KBibEditEntryDlg::KBibEditEntryDlg ( BibEntry *entry, QWidget *parent, const cha
 	abstractLabel->setAlignment ( AlignCenter );
 	l2->addWidget ( abstractEdit );
 	l2->addWidget ( abstractLabel );
-	mainTab->addTab ( abstractPage, "&Abstract" );
+	mainTab->addTab ( abstractPage, i18n("&Abstract") );
 	abstractEdit->hide();
-	//abstractPage->hide();
 
 
 	//Note tab
 	QWidget* noteTab = new QWidget ( mainTab );
 	QVBoxLayout* noteLayout = new QVBoxLayout ( noteTab, 10, KDialog::spacingHint() );
 	noteEdit = new KTextEdit ( noteTab );
+	//noteEdit->setTextFormat(RichText);
 	noteLabel = new QLabel ( i18n ( "This reference type does not have %1 field" ).arg ( QString::fromLatin1 ( "comment" ) ), noteTab );
 	noteLabel->setAlignment ( AlignCenter );
 	noteLayout->addWidget ( noteEdit );
 	noteLayout->addWidget ( noteLabel );
-	mainTab->addTab ( noteTab, "&Comment" );
+	mainTab->addTab ( noteTab, i18n("&Comment") );
 	noteEdit->hide();
 
 
@@ -268,23 +263,28 @@ KBibEditEntryDlg::KBibEditEntryDlg ( BibEntry *entry, QWidget *parent, const cha
 	QVBoxLayout* l3 = new QVBoxLayout ( page3, 10, KDialog::spacingHint() );
 	sourceEdit = new KTextEdit ( page3 );
 	l3->addWidget ( sourceEdit );
-	mainTab->addTab ( page3, "&Source" );
+	mainTab->addTab ( page3, i18n("&BibTeX Source") );
 
 
 
 
 	connect ( entryTypeSelect, SIGNAL ( activated ( int ) ), this, SLOT ( slotEntryTypeChange ( int ) ) ) ;
 	connect ( mainTab,SIGNAL ( currentChanged ( QWidget * ) ), this, SLOT ( slotTabChanged() ) );
+	connect ( keyField, SIGNAL ( textChanged ( const QString& ) ), SLOT ( slotSetModified() ) );
+	connect ( noteEdit, SIGNAL ( textChanged() ), SLOT ( slotSetModified() ) );
+	connect ( abstractEdit, SIGNAL ( textChanged() ), SLOT ( slotSetModified() ) );
+	connect ( sourceEdit, SIGNAL ( textChanged() ), SLOT ( slotSetModified() ) );
 
 	prevTabIndex = 0;
 	updateDlg ( entryTypeName );
 	updateContent ( m_entry );
-
+	slotSetModified ( false );
 
 
 
 
 	mainTab->setCurrentPage ( 0 );
+
 }
 
 KBibEditEntryDlg::~KBibEditEntryDlg()
@@ -310,12 +310,7 @@ KBibEditEntryDlg::~KBibEditEntryDlg()
 		delete lockKeyBttn;
 	rqFields.clear();
 
-	//    if (rqFields)
-	//        delete rqFields;
 	optFields.clear();
-	//    if (optFields)
-	//        delete optFields;
-
 
 	delete entryTypeSelect;
 	delete editTypeBttn;
@@ -378,9 +373,6 @@ void KBibEditEntryDlg::updateDlg ( QString entryTypeName )
 
 	if ( QString ( m_entry->getField ( QString::fromLatin1 ( "lockkey" ) ) ) =="Y" )
 	{
-		//lockKeyBttn->setText("Unlock Key");
-		//QPixmap pix = KGlobal::iconLoader()->loadIcon(QString::fromLatin1("unlock"), KIcon::Small);
-		//lockKeyBttn->setPixmap(pix);
 		lockKeyBttn->setIconSet ( QIconSet ( SmallIcon ( "unlock" ) ) );
 		lockKeyBttn->setSizePolicy ( QSizePolicy::Minimum, QSizePolicy::Minimum );
 		QToolTip::add ( lockKeyBttn, QString ( i18n ( "Unlock the citation key" ) ) );
@@ -390,9 +382,6 @@ void KBibEditEntryDlg::updateDlg ( QString entryTypeName )
 	}
 	else
 	{
-		//lockKeyBttn->setText("Lock Key");
-		//QPixmap pix = KGlobal::iconLoader()->loadIcon(QString::fromLatin1("lock"), KIcon::Small);
-		//lockKeyBttn->setPixmap(pix);
 		lockKeyBttn->setIconSet ( QIconSet ( SmallIcon ( "lock" ) ) );
 		lockKeyBttn->setSizePolicy ( QSizePolicy::Minimum, QSizePolicy::Minimum );
 		QToolTip::add ( lockKeyBttn, QString ( i18n ( "Lock the citation key" ) ) );
@@ -465,7 +454,7 @@ void KBibEditEntryDlg::updateDlg ( QString entryTypeName )
 						fieldEdit = monthFieldWg;
 						break;
 					}
-					
+
 					default:
 					{
 						GUI::LineFieldWidget *lineFieldWg = new  GUI::LineFieldWidget ( fn, field, macroKeys, rqBox );
@@ -478,6 +467,7 @@ void KBibEditEntryDlg::updateDlg ( QString entryTypeName )
 				}
 
 				fieldEdit->show();
+				connect ( fieldEdit, SIGNAL ( modified() ), SLOT ( slotSetModified() ) );
 				rqFields.append ( fieldEdit );
 				rqLayout->addWidget ( fieldEdit );
 
@@ -584,7 +574,7 @@ void KBibEditEntryDlg::updateDlg ( QString entryTypeName )
 					maxLabelWidth = w;
 
 				fieldEdit->show();
-
+				connect ( fieldEdit, SIGNAL ( modified() ), SLOT ( slotSetModified() ) );
 
 				optFields.append ( fieldEdit );
 				optLayout->addWidget ( fieldEdit );
@@ -682,7 +672,36 @@ void KBibEditEntryDlg::updateContent ( BibEntry *entry )
 	abstractEdit->setText ( entry->getField ( "abstract" ) );
 	//Note Tab
 	noteEdit->setText ( entry->getField ( "comment" ) );
+	slotSetModified(false);
+}
 
+
+void KBibEditEntryDlg::slotCancel()
+{
+	getBibEntry();
+	
+	if ( m_modified )
+	{
+		int want_save = KMessageBox::warningYesNoCancel ( this,  i18n ( "The current reference has been modified.\n"
+		                     "Do you want to apply the changes?" ), i18n ( "Unsaved Changes" ));
+		switch ( want_save )
+		{
+			case KMessageBox::Yes:
+				slotOk();
+				break;
+
+			case KMessageBox::No:
+				hide();
+				break;
+
+			case KMessageBox::Cancel:
+				break;
+		}
+	}
+	else
+		hide();
+	
+	
 }
 
 void KBibEditEntryDlg::slotEntryTypeChange ( int index )
@@ -702,7 +721,7 @@ void KBibEditEntryDlg::slotEntryTypeChange ( int index )
 
 	updateDlg ( type );
 	updateContent ( m_entry );
-
+	slotSetModified ( true );
 }
 
 void KBibEditEntryDlg::accept ( void )
@@ -749,6 +768,8 @@ BibEntry * KBibEditEntryDlg::getBibEntry ( void )
 	qst = keyField->text();
 	qst = qst.stripWhiteSpace();
 
+	QString lockkey = m_entry->getField(QString::fromLatin1("lockkey"));
+	
 	m_entry->setKey ( qst );
 
 	GUI::FieldWidget *field = rqFields.first();
@@ -780,7 +801,24 @@ BibEntry * KBibEditEntryDlg::getBibEntry ( void )
 
 	}
 
-	QListViewItem *it =extraFieldView->firstChild();
+	QListViewItem *it;
+	if (!m_modified){
+		it =extraFieldView->firstChild();
+		for ( int i = 0 ; i < extraFieldView->childCount(); i++ )
+		{
+			QString fn = it->text ( 1 );
+			QCheckListItem *itm = dynamic_cast<QCheckListItem*> ( it );
+			if ((m_entry->stringMacroIndicator(fn) && !(itm->isOn()) ) || 
+			   	(!(m_entry->stringMacroIndicator(fn)) && (itm->isOn()) )){
+				m_modified = true;
+				break;
+			}
+		}
+	}
+	
+	
+	it =extraFieldView->firstChild();
+	
 	m_entry->clearExtraField();
 	for ( int i = 0 ; i < extraFieldView->childCount(); i++ )
 	{
@@ -796,17 +834,13 @@ BibEntry * KBibEditEntryDlg::getBibEntry ( void )
 
 	}
 
-	/*
-	    if ( (BibEntryDefTable::self()->getBibEntryDef(m_entry->getEntryType()) )->getFieldIdx(QString::fromLatin1("abstract") ) >= 0)
-	        m_entry->setField(QString::fromLatin1("abstract"), abstractEdit->text() );
 
-		if ( (BibEntryDefTable::self()->getBibEntryDef(m_entry->getEntryType()) )->getFieldIdx(QString::fromLatin1("comment") ) >= 0)
-	        m_entry->setField(QString::fromLatin1("comment"), noteEdit->text() );
-	*/
 	if ( abstractEdit->isShown() )
 		m_entry->setField ( QString::fromLatin1 ( "abstract" ), abstractEdit->text() );
 	if ( noteEdit->isShown() )
 		m_entry->setField ( QString::fromLatin1 ( "comment" ), noteEdit->text() );
+	
+	m_entry->setField(QString::fromLatin1("lockkey"), lockkey);
 	return m_entry;
 
 }
@@ -893,6 +927,7 @@ void KBibEditEntryDlg::slotCreateKey()
 
 void KBibEditEntryDlg::slotLockKey()
 {
+
 	if ( QString ( m_entry->getField ( "lockkey" ) ) =="Y" )
 	{
 		//lockKeyBttn->setText("Lock Key");
@@ -915,6 +950,7 @@ void KBibEditEntryDlg::slotLockKey()
 		keyField->setEnabled ( false );
 		m_entry->setField ( "lockkey", "Y" );
 	}
+	slotSetModified ( true );
 
 }
 
@@ -930,7 +966,7 @@ void KBibEditEntryDlg::slotTabChanged ( void )
 		BibEntry *tmp_entry = processBibEntryFromString ( str.ascii(), dummy );
 		if ( !tmp_entry )
 		{
-			KMessageBox::error ( this, i18n ( "Errors in BibTex source." ) );
+			KMessageBox::error ( this, i18n ( "Errors in BibTeX source." ) );
 			QString entryTypeName = m_entry->getEntryType();
 			updateDlg ( entryTypeName );
 			updateContent ( m_entry );
@@ -986,7 +1022,9 @@ void KBibEditEntryDlg::slotTabChanged ( void )
 						st=st+",\n\t"+m_entry->getFieldName ( j ) +"="+ld+m_entry->getField ( j ) +rd;
 				}
 				st=st+"\n}\n";
+				sourceEdit->blockSignals(true);
 				sourceEdit->setText ( st );
+				sourceEdit->blockSignals(false);
 			}
 			prevTabIndex = mainTab->currentPageIndex();
 
@@ -1007,6 +1045,7 @@ void KBibEditEntryDlg::slotExtraFieldAdd()
 	extraFieldView->setSelected ( item, true );
 	item->setRenameEnabled ( 1,true );
 	item->setRenameEnabled ( 2,true );
+	slotSetModified(true);
 	updateExtraFieldGUI();
 	slotExtraFieldEdit();
 
@@ -1028,6 +1067,7 @@ void KBibEditEntryDlg::slotExtraFieldDelete()
 	{
 		extraFieldView->takeItem ( item );
 		updateExtraFieldGUI();
+		slotSetModified(true);
 	}
 }
 
@@ -1042,6 +1082,7 @@ void KBibEditEntryDlg::slotExtraFielItemRenamed ( QListViewItem * item, int col,
 			updateExtraFieldGUI();
 		}
 	}
+	slotSetModified(true);
 }
 
 void KBibEditEntryDlg::updateExtraFieldGUI()
@@ -1059,3 +1100,8 @@ void KBibEditEntryDlg::updateExtraFieldGUI()
 		extraFieldEditBtn->setEnabled ( false );
 	}
 }
+
+void KBibEditEntryDlg::slotSetModified ( bool modified )
+{
+	m_modified = modified;
+}
