@@ -76,59 +76,51 @@ void WOKSearcher::saveConfig(KConfig* config){
 }
 
 void WOKSearcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , const QString& value1, const QString& value2, const QString& value3, int operator1, int operator2) {
-    std::cerr << "Searching WOK\n";
-    m_started = true;
-
-    m_data.truncate(0);
-
-    m_url = KURL(m_host);
-    m_url.addPath(QString::fromLatin1(WOK_SEARCH_CGI));
-
-    QString str;
-    m_query = QString();
+ 
+    QString queryString;
 
     if (!value1.isEmpty())
     {
         switch(key1)
         {
         case Title:
-            m_query = QString::fromLatin1("TI=(");
+            queryString = QString::fromLatin1("TI=(");
             break;
 
         case Author:
-            m_query = QString::fromLatin1("AU=(");
+            queryString = QString::fromLatin1("AU=(");
             break;
 
         case Keyword:
-            m_query = QString::fromLatin1("TS=(");
+            queryString = QString::fromLatin1("TS=(");
             break;
 
         case Year:
-            m_query = QString::fromLatin1("PY=(");
+            queryString = QString::fromLatin1("PY=(");
             break;
 
         default:
             stop();
             return;
         }
-		m_query += value1 + QString::fromLatin1(")");
+		queryString += value1 + QString::fromLatin1(")");
     }
 
 
     if (!value2.isEmpty() )
     {
-        if (!m_query.isEmpty())
+        if (!queryString.isEmpty())
         {
             switch(operator1)
             {
             case 0:
-                m_query += QString::fromLatin1(" and ");
+                queryString += QString::fromLatin1(" and ");
                 break;
             case 1:
-                m_query += QString::fromLatin1(" or ");
+                queryString += QString::fromLatin1(" or ");
                 break;
             case 2:
-                m_query += QString::fromLatin1(" not ");
+                queryString += QString::fromLatin1(" not ");
                 break;
             default:
                 stop();
@@ -140,11 +132,58 @@ void WOKSearcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , const
         switch(key2)
         {
         case Title:
-            m_query += QString::fromLatin1("TI=(");
+            queryString += QString::fromLatin1("TI=(");
             break;
 
         case Author:
-            m_query += QString::fromLatin1("AU=(");
+            queryString += QString::fromLatin1("AU=(");
+            break;
+
+        case Keyword:
+            queryString += QString::fromLatin1("TS=(");
+            break;
+
+        case Year:
+            queryString += QString::fromLatin1("PY=(");
+            break;
+
+        default:
+            stop();
+            return;
+        }
+		queryString += value2 + QString::fromLatin1(")");
+
+    }
+
+    if (!value3.isEmpty() )
+    {
+        if (!queryString.isEmpty())
+        {
+            switch(operator2)
+            {
+            case 0:
+                queryString += QString::fromLatin1(" and ");
+                break;
+            case 1:
+                queryString += QString::fromLatin1(" or ");
+                break;
+            case 2:
+                queryString += QString::fromLatin1(" not ");
+                break;
+            default:
+                stop();
+                return;
+            }
+
+        }
+        switch(key3)
+        {
+        case Title:
+            queryString += QString::fromLatin1("TI=(");
+            break;
+
+        case Author:
+            queryString += QString::fromLatin1("AU=(");
             break;
 
         case Keyword:
@@ -159,56 +198,25 @@ void WOKSearcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , const
             stop();
             return;
         }
-		m_query += value2 + QString::fromLatin1(")");
+		queryString += value3 + QString::fromLatin1(")");
 
     }
+	search(queryString);
 
-    if (!value3.isEmpty() )
-    {
-        if (!m_query.isEmpty())
-        {
-            switch(operator2)
-            {
-            case 0:
-                m_query += QString::fromLatin1(" and ");
-                break;
-            case 1:
-                m_query += QString::fromLatin1(" or ");
-                break;
-            case 2:
-                m_query += QString::fromLatin1(" not ");
-                break;
-            default:
-                stop();
-                return;
-            }
 
-        }
-        switch(key3)
-        {
-        case Title:
-            m_query += str + QString::fromLatin1("TI=(");
-            break;
+}
 
-        case Author:
-            m_query += str + QString::fromLatin1("AU=(");
-            break;
+void WOKSearcher::search(QString queryString){
+    std::cerr << "Query string = " << queryString << "\n";
+    m_started = true;
 
-        case Keyword:
-            m_query += str + QString::fromLatin1("TS=(");
-            break;
+    m_data.truncate(0);
 
-        case Year:
-            m_query += str + QString::fromLatin1("PY=(");
-            break;
+    m_url = KURL(m_host);
+    m_url.addPath(QString::fromLatin1(WOK_SEARCH_CGI));
 
-        default:
-            stop();
-            return;
-        }
-		m_query += value3 + QString::fromLatin1(")");
-
-    }
+    QString str;
+    m_query = queryString;
 
 
     if (m_query.isEmpty())
@@ -230,7 +238,8 @@ void WOKSearcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , const
             SLOT(slotData(KIO::Job*, const QByteArray&)));
     connect(m_job, SIGNAL(result(KIO::Job*)),
             SLOT(slotComplete(KIO::Job*)));
-
+	
+	
 }
 
 void WOKSearcher::stop() {
