@@ -163,17 +163,7 @@ void Z3950Searcher::readConfig(KConfig* config_, const QString& group_)
 void Z3950Searcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , const QString& value1, const QString& value2, const QString& value3, int operator1, int operator2)
 {
 #if HAVE_YAZ
-    m_started = true;
-    if(m_host.isEmpty() || m_dbname.isEmpty())
-    {
-        std::cerr << "Z3950Fetcher::search() - settings are not set!" << endl;
-        stop();
-        return;
-    }
-    //  m_key = key_;
-    //  m_value = value_;
-    m_started = true;
-
+	QString queryString;
     QString svalue = value3;
     QRegExp rx1(QString::fromLatin1("['\"].*\\1"));
     if(!rx1.exactMatch(svalue))
@@ -181,25 +171,25 @@ void Z3950Searcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , cons
         svalue.prepend('"').append('"');
     }
 
-    m_pqn = QString("");
+
     if (!value3.isEmpty())
     {
         switch(key3)
         {
         case Title:
-            m_pqn = QString::fromLatin1("@attr 1=4 ") + svalue;
+            queryString = QString::fromLatin1("@attr 1=4 ") + svalue;
             break;
         case Author:
-            m_pqn = QString::fromLatin1(" @attr 1=1003 ") + svalue;
+            queryString = QString::fromLatin1(" @attr 1=1003 ") + svalue;
             break;
         case Keyword:
-            m_pqn = QString::fromLatin1("@attr 1=21 ") + svalue;
+            queryString = QString::fromLatin1("@attr 1=21 ") + svalue;
             break;
         case Year:
-            m_pqn = QString::fromLatin1("@attr 1=31 ") + svalue;
+            queryString = QString::fromLatin1("@attr 1=31 ") + svalue;
             break;
         case All:
-            m_pqn = QString::fromLatin1("@attr 1=1016 ") + svalue;
+            queryString = QString::fromLatin1("@attr 1=1016 ") + svalue;
             break;
         default:
             std::cerr << "key not recognized: " << key3 << endl;
@@ -219,19 +209,19 @@ void Z3950Searcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , cons
         switch(key2)
         {
         case Title:
-            m_pqn = QString::fromLatin1("@attr 1=4 ") + svalue+ m_pqn;
+            queryString = QString::fromLatin1("@attr 1=4 ") + svalue+ queryString;
             break;
         case Author:
-            m_pqn = QString::fromLatin1(" @attr 1=1003 ") + svalue + m_pqn;
+            queryString = QString::fromLatin1(" @attr 1=1003 ") + svalue + queryString;
             break;
         case Keyword:
-            m_pqn = QString::fromLatin1("@attr 1=21 ") + svalue + m_pqn;
+            queryString = QString::fromLatin1("@attr 1=21 ") + svalue + queryString;
             break;
         case Year:
-            m_pqn = QString::fromLatin1("@attr 1=31 ") + svalue + m_pqn;
+            queryString = QString::fromLatin1("@attr 1=31 ") + svalue + queryString;
             break;
         case All:
-            m_pqn = QString::fromLatin1("@attr 1=1016 ") + svalue + m_pqn;
+            queryString = QString::fromLatin1("@attr 1=1016 ") + svalue + queryString;
             break;
         default:
             std::cerr << "key not recognized: " << key2 << endl;
@@ -243,13 +233,13 @@ void Z3950Searcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , cons
             switch(operator2)
             {
             case 0:
-                m_pqn = QString::fromLatin1(" @and ") + m_pqn;
+                queryString = QString::fromLatin1(" @and ") + queryString;
                 break;
             case 1:
-                m_pqn = QString::fromLatin1(" @or ") + m_pqn;
+                queryString = QString::fromLatin1(" @or ") + queryString;
                 break;
             default:
-                m_pqn = QString::fromLatin1(" @not ") + m_pqn;
+                queryString = QString::fromLatin1(" @not ") + queryString;
                 break;
             }
         }
@@ -266,19 +256,19 @@ void Z3950Searcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , cons
         switch(key1)
         {
         case Title:
-            m_pqn = QString::fromLatin1("@attr 1=4 ") + svalue+ m_pqn;
+            queryString = QString::fromLatin1("@attr 1=4 ") + svalue+ queryString;
             break;
         case Author:
-            m_pqn = QString::fromLatin1(" @attr 1=1003 ") + svalue + m_pqn;
+            queryString = QString::fromLatin1(" @attr 1=1004 ") + svalue + queryString;
             break;
         case Keyword:
-            m_pqn = QString::fromLatin1("@attr 1=21 ") + svalue + m_pqn;
+            queryString = QString::fromLatin1("@attr 1=21 ") + svalue + queryString;
             break;
         case Year:
-            m_pqn = QString::fromLatin1("@attr 1=31 ") + svalue + m_pqn;
+            queryString = QString::fromLatin1("@attr 1=31 ") + svalue + queryString;
             break;
         case All:
-            m_pqn = QString::fromLatin1("@attr 1=1016 ") + svalue + m_pqn;
+            queryString = QString::fromLatin1("@attr 1=1016 ") + svalue + queryString;
             break;
         default:
             std::cerr << "key not recognized: " << key1 << endl;
@@ -291,13 +281,13 @@ void Z3950Searcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , cons
             switch(operator2)
             {
             case 0:
-                m_pqn = QString::fromLatin1(" @and ") + m_pqn;
+                queryString = QString::fromLatin1(" @and ") + queryString;
                 break;
             case 1:
-                m_pqn = QString::fromLatin1(" @or ") + m_pqn;
+                queryString = QString::fromLatin1(" @or ") + queryString;
                 break;
             default:
-                m_pqn = QString::fromLatin1(" @not ") + m_pqn;
+                queryString = QString::fromLatin1(" @not ") + queryString;
                 break;
             }
         }
@@ -306,13 +296,13 @@ void Z3950Searcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , cons
             switch(operator1)
             {
             case 0:
-                m_pqn = QString::fromLatin1(" @and ") + m_pqn;
+                queryString = QString::fromLatin1(" @and ") + queryString;
                 break;
             case 1:
-                m_pqn = QString::fromLatin1(" @or ") + m_pqn;
+                queryString = QString::fromLatin1(" @or ") + queryString;
                 break;
             default:
-                m_pqn = QString::fromLatin1(" @not ") + m_pqn;
+                queryString = QString::fromLatin1(" @not ") + queryString;
                 break;
             }
 
@@ -322,7 +312,7 @@ void Z3950Searcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , cons
 
     //  m_pqn = QString::fromLatin1("@attr 1=7 0253333490");
 
-    processSearch();
+    search(queryString);
 #else // HAVE_YAZ
     Q_UNUSED(key1);
     Q_UNUSED(value1);
@@ -335,6 +325,30 @@ void Z3950Searcher::search(SearchKey key1, SearchKey key2, SearchKey key3 , cons
 #endif
 
 
+}
+
+void Z3950Searcher::search(QString queryString){
+#if HAVE_YAZ
+//	std::cerr << "Query String = " << queryString << "\n";
+    m_started = true;
+    if(m_host.isEmpty() || m_dbname.isEmpty())
+    {
+        std::cerr << "Z3950Fetcher::search() - settings are not set!" << endl;
+        stop();
+        return;
+    }
+ 
+    m_started = true;
+
+	m_pqn = queryString;
+	
+    processSearch();
+#else // HAVE_YAZ
+	Q_UNUSED(queryString);
+    stop();
+    return;
+#endif	
+	
 }
 
 void Z3950Searcher::processSearch()
@@ -408,7 +422,9 @@ void Z3950Searcher::customEvent(QCustomEvent* event_)
 
 void Z3950Searcher::handleResult(const QString& result_)
 {
-    if(result_.isEmpty())
+//	std::cerr << result_.latin1();
+	
+	if(result_.isEmpty())
     {
         std::cerr << "Z3950Searcher::process() - empty record found, maybe the character encoding or record format is wrong?" << endl;
         return;
@@ -674,7 +690,7 @@ Z3950ConfigWidget::Z3950ConfigWidget(QWidget* parent_, Z3950Searcher* searcher_/
     m_passwordEdit->setEchoMode(QLineEdit::Password);
     l->addWidget(m_passwordEdit, row, 1);
     w = i18n("Enter the authentication password used by the z39.50 database. Most servers "
-             "do not need one. The password will be saved in plain text in the Tellico "
+             "do not need one. The password will be saved in plain text in the Kbib "
              "configuration file.");
     QWhatsThis::add(label, w);
     QWhatsThis::add(m_passwordEdit, w);
